==> zio-aws-devopsguru_2.12-5.17.161.1-sources.jar: zio/aws/devopsguru/model/GetCostEstimationRequest.scala <==
package zio.aws.devopsguru.model
import zio.aws.devopsguru.model.primitives.UuidNextToken
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class GetCostEstimationRequest(
    nextToken: Option[UuidNextToken] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.devopsguru.model.GetCostEstimationRequest = {
    import GetCostEstimationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.devopsguru.model.GetCostEstimationRequest
      .builder()
      .optionallyWith(
        nextToken.map(value => UuidNextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.devopsguru.model.GetCostEstimationRequest.ReadOnly =
    zio.aws.devopsguru.model.GetCostEstimationRequest.wrap(buildAwsValue())
}
object GetCostEstimationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.devopsguru.model.GetCostEstimationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.devopsguru.model.GetCostEstimationRequest =
      zio.aws.devopsguru.model
        .GetCostEstimationRequest(nextToken.map(value => value))
    def nextToken: Option[UuidNextToken]
    def getNextToken: ZIO[Any, AwsError, UuidNextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.devopsguru.model.GetCostEstimationRequest
  ) extends zio.aws.devopsguru.model.GetCostEstimationRequest.ReadOnly {
    override val nextToken: Option[UuidNextToken] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.devopsguru.model.primitives.UuidNextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.devopsguru.model.GetCostEstimationRequest
  ): zio.aws.devopsguru.model.GetCostEstimationRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-devopsguru_2.13-5.17.208.2-sources.jar: zio/aws/devopsguru/model/GetCostEstimationRequest.scala <==
package zio.aws.devopsguru.model
import zio.aws.devopsguru.model.primitives.UuidNextToken
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class GetCostEstimationRequest(
    nextToken: Optional[UuidNextToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.devopsguru.model.GetCostEstimationRequest = {
    import GetCostEstimationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.devopsguru.model.GetCostEstimationRequest
      .builder()
      .optionallyWith(
        nextToken.map(value => UuidNextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.devopsguru.model.GetCostEstimationRequest.ReadOnly =
    zio.aws.devopsguru.model.GetCostEstimationRequest.wrap(buildAwsValue())
}
object GetCostEstimationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.devopsguru.model.GetCostEstimationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.devopsguru.model.GetCostEstimationRequest =
      zio.aws.devopsguru.model
        .GetCostEstimationRequest(nextToken.map(value => value))
    def nextToken: Optional[UuidNextToken]
    def getNextToken: ZIO[Any, AwsError, UuidNextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.devopsguru.model.GetCostEstimationRequest
  ) extends zio.aws.devopsguru.model.GetCostEstimationRequest.ReadOnly {
    override val nextToken: Optional[UuidNextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.devopsguru.model.primitives.UuidNextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.devopsguru.model.GetCostEstimationRequest
  ): zio.aws.devopsguru.model.GetCostEstimationRequest.ReadOnly = new Wrapper(
    impl
  )
}
